@@ -1,5 +1,7 @@
 """Errors"""
 
+class Rejection(RuntimeError):
+    """Cannot push into worker db"""
 
 class DependencyError(ImportError):
     """Specific dependency is missing"""
@@ -30,3 +32,12 @@ class ObjectRemovedError(BaseException):
 
 class CuteDemonLordException(Exception):
     """A demon lord (cute one, somehow a dude) aborts an SQL statement"""
+
+class FeatureGatekeep(ValueError):
+    """A feature is gatekeeped"""
+
+class VersionError(FeatureGatekeep):
+    """Current version cannot use this feature"""
+
+class ImplementationWarning(FutureWarning):
+    """The implementation of specific feature is not supported"""
